@@ -1,15 +1,23 @@
 # -*- coding: utf-8 -*-
-from warnings import warn
-
 import matplotlib
 import matplotlib.pyplot as plt
 import numpy as np
+import pandas as pd
 
-from ..misc import NeuroKitWarning, expspace
+from ..misc import expspace
 
 
-def fractal_dfa(signal, windows="default", overlap=True, integrate=True,
-                order=1, multifractal=False, q=2, show=False):
+def fractal_dfa(
+    signal,
+    windows="default",
+    overlap=True,
+    integrate=True,
+    order=1,
+    multifractal=False,
+    q="default",
+    show=False,
+    **kwargs,
+):
     """(Multifractal) Detrended Fluctuation Analysis (DFA or MFDFA).
 
     Python implementation of Detrended Fluctuation Analysis (DFA) or
@@ -25,18 +33,16 @@ def fractal_dfa(signal, windows="default", overlap=True, integrate=True,
     ----------
     signal : Union[list, np.array, pd.Series]
         The signal (i.e., a time series) in the form of a vector of values.
-
+        or dataframe.
     windows : list
         A list containing the lengths of the windows (number of data points in
         each subseries). Also referred to as 'lag' or 'scale'. If 'default',
         will set it to a logarithmic scale (so that each window scale has the
         same weight) with a minimum of 4 and maximum of a tenth of the length
         (to have more than 10 windows to calculate the average fluctuation).
-
     overlap : bool
         Defaults to True, where the windows will have a 50% overlap
         with each other, otherwise non-overlapping windows will be used.
-
     integrate : bool
         It is common practice to convert the signal to a random walk (i.e.,
         detrend and integrate, which corresponds to the signal 'profile'). Note
@@ -45,49 +51,52 @@ def fractal_dfa(signal, windows="default", overlap=True, integrate=True,
         strongly anticorrelated signals, this transformation should be applied
         two times (i.e., provide `np.cumsum(signal - np.mean(signal))` instead
         of `signal`).
-
     order : int
-
        The order of the polynomial trend for detrending, 1 for the linear trend.
-
     multifractal : bool
         If true, compute Multifractal Detrended Fluctuation Analysis (MFDFA), in
         which case the argument `q` is taken into account.
-
-    q : list or np.array (default `2`)
+    q : Union[int, list, np.array]
         The sequence of fractal exponents when `multifractal=True`. Must be a
         sequence between `-10` and `10` (note that zero will be removed, since
-        the code does not converge there). Setting `q = 2` (default) gives a
+        the code does not converge there). Setting `q = 2` (default for DFA) gives a
         result of a standard DFA. For instance, Ihlen (2012) uses
-        `q = [-5, -3, -1, 0, 1, 3, 5]`. In general, positive q moments amplify
-        the contribution of fractal components with larger amplitude and
-        negative q moments amplify the contribution of fractal with smaller
-        amplitude (Kantelhardt et al., 2002)
-
+        `q = [-5, -3, -1, 0, 1, 3, 5]` (default when for multifractal).
+        In general, positive q moments amplify the contribution of fractal components with larger
+        amplitude and negative q moments amplify the contribution of fractal with smaller
+        amplitude (Kantelhardt et al., 2002).
     show : bool
         Visualise the trend between the window size and the fluctuations.
+    **kwargs : optional
+        Currently not used.
 
     Returns
     ----------
-    dfa : dict
-        If `multifractal` is False, the dictionary contains q value, a series of windows, fluctuations of each window and the
-        slopes value of the log2(windows) versus log2(fluctuations) plot. If `multifractal` is True, the dictionary
-        additionally contains the parameters of the singularity spectrum (scaling exponents, singularity dimension, singularity
-        strength; see `singularity_spectrum()` for more information).
+    dfa : float or np.array
+        If `multifractal` is False, one DFA value is returned for a single time series.
+    parameters : dict
+        A dictionary containing additional information regarding the parameters used
+        to compute DFA. If `multifractal` is False, the dictionary contains q value, a
+        series of windows, fluctuations of each window and the
+        slopes value of the log2(windows) versus log2(fluctuations) plot. If
+        `multifractal` is True, the dictionary additionally contains the
+        parameters of the singularity spectrum (scaling exponents, singularity dimension,
+        singularity strength; see `_singularity_spectrum()` for more information).
 
+    See Also
+    --------
+    complexity_hurst
 
     Examples
     ----------
     >>> import neurokit2 as nk
-    >>> import numpy as np
     >>>
     >>> signal = nk.signal_simulate(duration=10, noise=0.05)
-    >>> dfa1 = nk.fractal_dfa(signal, show=True)
+    >>> dfa1, parameters1 = nk.fractal_dfa(signal, show=True)
     >>> dfa1 #doctest: +SKIP
-    >>> dfa2 = nk.fractal_mfdfa(signal, q=np.arange(-5, 6), show=True)
+    >>> dfa2, parameters2 = nk.fractal_mfdfa(signal, q=[-5, -3, -1, 0, 1, 3, 5], show=True)
     >>> dfa2 #doctest: +SKIP
 
-
     References
     -----------
     - Ihlen, E. A. F. E. (2012). Introduction to multifractal detrended
@@ -111,68 +120,80 @@ def fractal_dfa(signal, windows="default", overlap=True, integrate=True,
 
     """
     # Sanity checks
+    if isinstance(signal, (np.ndarray, pd.DataFrame)) and signal.ndim > 1:
+        raise ValueError(
+            "Multidimensional inputs (e.g., matrices or multichannel data) are not supported yet."
+        )
+
     n = len(signal)
     windows = _fractal_dfa_findwindows(n, windows)
-    _fractal_dfa_findwindows_warning(windows, n)  # Return warning for too short windows
+
+    # Sanitize fractal power (cannot be close to 0)
+    q = _sanitize_q(q, multifractal=multifractal)
 
     # Preprocessing
     if integrate is True:
-        signal = np.cumsum(signal - np.mean(signal))  # Get signal profile
-
-    # Sanitize fractal power (cannot be close to 0)
-    q = _cleanse_q(q, multifractal=multifractal)
-
-    # obtain the windows and fluctuations
-    windows, fluctuations = _fractal_dfa(signal=signal,
-                                         windows=windows,
-                                         overlap=overlap,
-                                         integrate=integrate,
-                                         order=order,
-                                         multifractal=multifractal,
-                                         q=q
-                                         )
+        # Get signal profile
+        signal = np.cumsum(signal - np.mean(signal))
 
+    # obtain the windows, fluctuations
+    windows, fluctuations = _fractal_dfa(
+        signal=signal,
+        windows=windows,
+        overlap=overlap,
+        integrate=integrate,
+        order=order,
+        multifractal=multifractal,
+        q=q,
+    )
     if len(fluctuations) == 0:
         return np.nan
 
+    # Get slopes
     slopes = _slopes(windows, fluctuations, q)
-    out = {'q' : q[:, 0],
-           'windows' : windows,
-           'fluctuations' : fluctuations,
-           'slopes' : slopes}
+    if len(slopes) == 1:
+        slopes = slopes[0]
+
+    # Prepare output
+    parameters = {"q": q[:, 0], "windows": windows, "fluctuations": fluctuations}
 
     if multifractal is True:
-        singularity = singularity_spectrum(windows=windows,
-                                           fluctuations=fluctuations,
-                                           q=q,
-                                           slopes=slopes)
-        out.update(singularity)
+        singularity = _singularity_spectrum(
+            windows=windows, fluctuations=fluctuations, q=q, slopes=slopes
+        )
+        parameters.update(singularity)
+
+
+
 
     # Plot if show is True.
     if show is True:
         if multifractal is True:
-            _fractal_mdfa_plot(windows=windows,
-                               fluctuations=fluctuations,
-                               multifractal=multifractal,
-                               q=q,
-                               tau=out['tau'],
-                               hq=out['hq'],
-                               Dq=out['Dq'])
+            _fractal_mdfa_plot(
+                windows=windows,
+                fluctuations=fluctuations,
+                multifractal=multifractal,
+                q=q,
+                tau=parameters["tau"],
+                hq=parameters["hq"],
+                Dq=parameters["Dq"],
+            )
         else:
-            _fractal_dfa_plot(windows=windows,
-                              fluctuations=fluctuations,
-                              multifractal=multifractal,
-                              q=q)
+            _fractal_dfa_plot(
+                windows=windows, fluctuations=fluctuations, multifractal=multifractal, q=q
+            )
+
+    return slopes, parameters
 
-    return out
 
 # =============================================================================
 # Utilities
 # =============================================================================
 
 
-def _fractal_dfa(signal, windows="default", overlap=True, integrate=True,
-                 order=1, multifractal=False, q=2):
+def _fractal_dfa(
+    signal, windows="default", overlap=True, integrate=True, order=1, multifractal=False, q=2
+):
     """Does the heavy lifting for `fractal_dfa()`.
 
     Returns
@@ -199,11 +220,7 @@ def _fractal_dfa(signal, windows="default", overlap=True, integrate=True,
         trends = _fractal_dfa_trends(segments, window, order=order)
 
         # Get local fluctuation
-        fluctuations[i] = _fractal_dfa_fluctuation(segments,
-                                                   trends,
-                                                   multifractal,
-                                                   q
-                                                   )
+        fluctuations[i] = _fractal_dfa_fluctuation(segments, trends, multifractal, q)
 
     # I would not advise this part. I understand the need to remove zeros, but I
     # would instead suggest masking it with numpy.ma masked arrays. Note that
@@ -217,7 +234,6 @@ def _fractal_dfa(signal, windows="default", overlap=True, integrate=True,
     return windows, fluctuations
 
 
-
 # =============================================================================
 #  Utils MFDFA
 # =============================================================================
@@ -232,7 +248,8 @@ def _fractal_dfa(signal, windows="default", overlap=True, integrate=True,
 # (https://github.com/LRydin/MFDFA). It is included here by the author and
 # altered to fit NK to the best of its extent.
 
-def singularity_spectrum(windows, fluctuations, q, slopes):
+
+def _singularity_spectrum(windows, fluctuations, q, slopes):
     """Extract the slopes of the fluctuation function to futher obtain the
     singularity strength `α` (or Hölder exponents) and singularity spectrum
     `f(α)` (or fractal dimension). This is iconically shaped as an inverse
@@ -298,17 +315,21 @@ def singularity_spectrum(windows, fluctuations, q, slopes):
     Dq = q[:, 0] * hq - tau
 
     # Calculate the singularity
-    ExpRange = np.max(hq) - np.min(hq)
-    ExpMean = np.mean(hq)
-    DimRange = np.max(Dq) - np.min(Dq)
-    DimMean = np.mean(Dq)
-    out = {'tau': tau,
-           'hq': hq,
-           'Dq': Dq,
-           'ExpRange': ExpRange,
-           'ExpMean': ExpMean,
-           'DimRange': DimRange,
-           'DimMean': DimMean}
+    ExpRange = np.nanmax(hq) - np.nanmin(hq)
+    ExpMean = np.nanmean(hq)
+    DimRange = np.nanmax(Dq) - np.nanmin(Dq)
+    DimMean = np.nanmean(Dq)
+
+    # Prepare output
+    out = {
+        "tau": tau,
+        "hq": hq,
+        "Dq": Dq,
+        "ExpRange": ExpRange,
+        "ExpMean": ExpMean,
+        "DimRange": DimRange,
+        "DimMean": DimMean,
+    }
 
     return out
 
@@ -317,19 +338,15 @@ def singularity_spectrum(windows, fluctuations, q, slopes):
 #  Utils
 # =============================================================================
 
-def _cleanse_q(q=2, multifractal=False):
+
+def _sanitize_q(q=2, multifractal=False):
     # TODO: Add log calculator for q ≈ 0
 
     # Enforce DFA in case 'multifractal = False' but 'q' is not 2
-    if multifractal is False:
-        q = 2
-    else:
-        if isinstance(q, int):
-            warn(
-                "For multifractal DFA, q needs to be a list. "
-                "Using the default value of q = [-5, -3, -1, 0, 1, 3, 5]",
-                category=NeuroKitWarning
-            )
+    if isinstance(q, str):
+        if multifractal is False:
+            q = 2
+        else:
             q = [-5, -3, -1, 0, 1, 3, 5]
 
     # Fractal powers as floats
@@ -358,13 +375,13 @@ def _slopes(windows, fluctuations, q):
 
     # Ensure mfdfa has the same q-power entries as q
     if fluctuations.shape[1] != q.shape[0]:
-        raise ValueError(
-            "Fluctuation function and q powers don't match in dimension.")
+        raise ValueError("Fluctuation function and q powers don't match in dimension.")
 
     # Allocated array for slopes
     slopes = np.zeros(len(q))
     # Find slopes of each q-power
     for i in range(len(q)):
+        # if fluctiations is zero, log2 wil encounter zero division
         old_setting = np.seterr(divide="ignore", invalid="ignore")
         slopes[i] = np.polyfit(np.log2(windows), np.log2(fluctuations[:, i]), 1)[0]
         np.seterr(**old_setting)
@@ -381,35 +398,27 @@ def _fractal_dfa_findwindows(n, windows="default"):
     if windows is None or isinstance(windows, str):
         windows = int(n / 10)
 
-    # Default windows sequence
+    # See https://github.com/neuropsychology/NeuroKit/issues/206
     if isinstance(windows, int):
-        windows = expspace(
-            10, int(n / 10), windows, base=2
-        )  # see https://github.com/neuropsychology/NeuroKit/issues/206
+        windows = expspace(10, int(n / 10), windows, base=2)
         windows = np.unique(windows)  # keep only unique
 
-    return windows
-
-
-def _fractal_dfa_findwindows_warning(windows, n):
-
+    # Sanity checks (return warning for too short windows)
     # Check windows
     if len(windows) < 2:
-        raise ValueError(
-            "NeuroKit error: fractal_dfa(): more than one window is needed."
-        )
+        raise ValueError("NeuroKit error: more than one window is needed. Increase 'windows'.")
 
     if np.min(windows) < 2:
         raise ValueError(
-            "NeuroKit error: fractal_dfa(): there must be at least 2 data "
-            "points in each window"
+            "NeuroKit error: there must be at least 2 data points in each window. Decrease 'windows'."
         )
     if np.max(windows) >= n:
         raise ValueError(
-            "NeuroKit error: fractal_dfa(): the window cannot contain more data"
-            " points than the" "time series."
+            "NeuroKit error: the window cannot contain more data points than the time series. Decrease 'windows'."
         )
 
+    return windows
+
 
 def _fractal_dfa_getwindow(signal, n, window, overlap=True):
     # This function reshapes the segments from a one-dimensional array to a
@@ -417,9 +426,7 @@ def _fractal_dfa_getwindow(signal, n, window, overlap=True):
     # overlapping partitions of the data
 
     if overlap:
-        segments = np.array([signal[i : i + window]
-                             for i in np.arange(0, n - window, window // 2)
-                             ])
+        segments = np.array([signal[i : i + window] for i in np.arange(0, n - window, window // 2)])
     else:
         segments = signal[: n - (n % window)]
         segments = segments.reshape((signal.shape[0] // window, window))
@@ -433,9 +440,7 @@ def _fractal_dfa_trends(segments, window, order=1):
     coefs = np.polyfit(x[:window], segments.T, order).T
 
     # TODO: Could this be optimized? Something like np.polyval(x[:window],coefs)
-    trends = np.array([np.polyval(coefs[j], x)
-                       for j in np.arange(len(segments))
-                       ])
+    trends = np.array([np.polyval(coefs[j], x) for j in np.arange(len(segments))])
 
     return trends
 
@@ -450,8 +455,7 @@ def _fractal_dfa_fluctuation(segments, trends, multifractal=False, q=2):
         # and of q
         # ignore division by 0 warning
         old_setting = np.seterr(divide="ignore", invalid="ignore")
-        fluctuation = \
-            np.float_power(np.mean(np.float_power(var, q / 2), axis=1), 1 / q.T)
+        fluctuation = np.float_power(np.mean(np.float_power(var, q / 2), axis=1), 1 / q.T)
         np.seterr(**old_setting)
 
     else:
@@ -461,6 +465,7 @@ def _fractal_dfa_fluctuation(segments, trends, multifractal=False, q=2):
 
     return fluctuation
 
+
 # =============================================================================
 #  Plots
 # =============================================================================
@@ -470,9 +475,7 @@ def _fractal_mdfa_plot(windows, fluctuations, multifractal, q, tau, hq, Dq):
 
     # Prepare figure
     fig = plt.figure(constrained_layout=False)
-    spec = matplotlib.gridspec.GridSpec(
-        ncols=2, nrows=2
-    )
+    spec = matplotlib.gridspec.GridSpec(ncols=2, nrows=2)
 
     ax_fluctuation = fig.add_subplot(spec[0, 0])
     ax_spectrum = fig.add_subplot(spec[0, 1])
@@ -482,22 +485,27 @@ def _fractal_mdfa_plot(windows, fluctuations, multifractal, q, tau, hq, Dq):
     n = len(q)
     colors = plt.cm.plasma(np.linspace(0, 1, n))
 
-    # Plot the fluctuation plot
     # Plot the points
     for i in range(len(q)):
         polyfit = np.polyfit(np.log2(windows), np.log2(fluctuations[:, i]), 1)
-        ax_fluctuation.loglog(windows, fluctuations, "bo", c='#d2dade', markersize=5, base=2)
+        ax_fluctuation.loglog(windows, fluctuations, "o", c="#d2dade", markersize=5, base=2)
     # Plot the polyfit line
     for i in range(len(q)):
         polyfit = np.polyfit(np.log2(windows), np.log2(fluctuations[:, i]), 1)
+        if i == 0:
+            ax_fluctuation.plot(
+                [],
+                label=(r"$\alpha$ = {:.3f}, q = {:.1f}").format(polyfit[0], q[0][0]),
+                c=colors[0],
+            )
+        elif i == (len(q) - 1):
+            ax_fluctuation.plot(
+                [],
+                label=(r"$\alpha$ = {:.3f}, q = {:.1f}").format(polyfit[0], q[-1][0]),
+                c=colors[-1],
+            )
         fluctfit = 2 ** np.polyval(polyfit, np.log2(windows))
-        ax_fluctuation.loglog(windows, fluctfit, "r", c=colors[i], base=2, label='_no_legend_')
-    ax_fluctuation.plot([],
-                        label=(r"$\alpha$ = {:.3f}, q={:.1f}").format(polyfit[0], q[0][0]),
-                        c=colors[0])
-    ax_fluctuation.plot([],
-                        label=(r"$\alpha$ = {:.3f}, q={:.1f}").format(polyfit[0], q[-1][0]),
-                        c=colors[-1])
+        ax_fluctuation.loglog(windows, fluctfit, c=colors[i], base=2, label="_no_legend_")
 
     # Plot the singularity spectrum
     _singularity_spectrum_plot(hq, Dq, ax=ax_spectrum)
@@ -508,8 +516,8 @@ def _fractal_mdfa_plot(windows, fluctuations, multifractal, q, tau, hq, Dq):
 
     ax_fluctuation.set_xlabel(r"$\log_{2}$(Window)")
     ax_fluctuation.set_ylabel(r"$\log_{2}$(Fluctuation)")
+    fig.suptitle("Multifractal Detrended Fluctuation Analysis (MFDFA)")
     ax_fluctuation.legend(loc="lower right")
-    fig.suptitle('Multifractal Detrended Fluctuation Analysis')
 
     return None
 
@@ -518,11 +526,11 @@ def _fractal_dfa_plot(windows, fluctuations, multifractal, q):
 
     polyfit = np.polyfit(np.log2(windows), np.log2(fluctuations), 1)
     fluctfit = 2 ** np.polyval(polyfit, np.log2(windows))
-    plt.loglog(windows, fluctuations, "bo", c='#90A4AE')
-    plt.loglog(windows, fluctfit, "r", c='#E91E63',
-               label=r"$\alpha$ = {:.3f}".format(polyfit[0][0]))
+    plt.loglog(windows, fluctuations, "o", c="#90A4AE")
+    plt.loglog(windows, fluctfit, c="#E91E63", label=r"$\alpha$ = {:.3f}".format(polyfit[0][0]))
+
     plt.legend(loc="lower right")
-    plt.title('Detrended Fluctuation Analysis')
+    plt.title("Detrended Fluctuation Analysis")
 
     return None
 
@@ -534,10 +542,10 @@ def _singularity_spectrum_plot(hq, Dq, ax=None):
     Parameters
     ----------
     hq: np.array
-        Singularity strength `hq` as calculated with `singularity_spectrum()`.
+        Singularity strength `hq` as calculated with `_singularity_spectrum()`.
 
     Dq: np.array
-        Singularity spectrum `Dq` as calculated with `singularity_spectrum()`.
+        Singularity spectrum `Dq` as calculated with `_singularity_spectrum()`.
 
     Returns
     -------
@@ -550,12 +558,11 @@ def _singularity_spectrum_plot(hq, Dq, ax=None):
     `MFDFA <https://github.com/LRydin/MFDFA/>`_ and ported here by the same.
 
     """
+    # ax.set_title("Singularity Spectrum")
+    ax.set_ylabel(r"Singularity dimension ($D_q$)")
+    ax.set_xlabel(r"Singularity exponent ($h_q$)")
 
-    ax.plot(hq, Dq, 'o-', c='#FFC107')
-
-#    ax.set_title("Singularity Spectrum")
-    ax.set_ylabel(r'Singularity dimension ($D_q$)')
-    ax.set_xlabel(r'Singularity exponent ($h_q$)')
+    ax.plot(hq, Dq, "o-", c="#FFC107")
 
     return None
 
@@ -580,11 +587,11 @@ def _scaling_exponents_plot(q, tau, ax=None):
 
     """
 
-    ax.plot(q, tau, 'o-', c='#E91E63')
+    #    ax.set_title("Scaling Exponents")
+    ax.set_ylabel(r"Scaling exponents ($τ_q$)")
+    ax.set_xlabel(r"Multifractal parameter ($q$)")
 
-#    ax.set_title("Scaling Exponents")
-    ax.set_ylabel(r'Scaling exponents ($τ_q$)')
-    ax.set_xlabel(r'Multifractal parameter ($q$)')
+    ax.plot(q, tau, "o-", c="#E91E63")
 
     return None
 
@@ -610,10 +617,10 @@ def _hurst_exponents_plot(q, hq, ax=None):
 
     """
 
-    ax.plot(q, hq, 'o-', c='#2196F3')
+    #    ax.set_title("Generalised Hurst Exponents")
+    ax.set_ylabel(r"Generalized Hurst Exponents ($h_q$)")
+    ax.set_xlabel(r"Multifractal parameter ($q$)")
 
-#    ax.set_title("Generalised Hurst Exponents")
-    ax.set_ylabel(r'Generalized Hurst Exponents ($h_q$)')
-    ax.set_xlabel(r'Multifractal parameter ($q$)')
+    ax.plot(q, hq, "o-", c="#2196F3")
 
     return None
