@@ -3,5 +3,6 @@
 from .data import data
 from .read_acqknowledge import read_acqknowledge
 from .read_bitalino import read_bitalino
+from .write_csv import write_csv
 
-__all__ = ["read_acqknowledge", "read_bitalino", "data"]
+__all__ = ["read_acqknowledge", "read_bitalino", "data", "write_csv"]
