@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 from warnings import warn
 
+import matplotlib.pyplot as plt
 import numpy as np
 import scipy.signal
 
@@ -16,6 +17,7 @@ def signal_filter(
     order=2,
     window_size="default",
     powerline=50,
+    show=False,
 ):
     """Filter a signal using 'butterworth', 'fir' or 'savgol' filters.
 
@@ -46,6 +48,8 @@ def signal_filter(
         (101 if the sampling rate is 1000 Hz).
     powerline : int
         Only used if method is 'powerline'. The powerline frequency (normally 50 Hz or 60 Hz).
+    show : bool
+        If ``True``, plot the filtered signal as an overlay of the original.
 
     See Also
     --------
@@ -114,11 +118,10 @@ def signal_filter(
     """
     method = method.lower()
 
-
     if method in ["sg", "savgol", "savitzky-golay"]:
         filtered = _signal_filter_savgol(signal, sampling_rate, order, window_size=window_size)
     elif method in ["powerline"]:
-            filtered = _signal_filter_powerline(signal, sampling_rate, powerline)
+        filtered = _signal_filter_powerline(signal, sampling_rate, powerline)
     else:
 
         # Sanity checks
@@ -134,13 +137,20 @@ def signal_filter(
         elif method in ["bessel"]:
             filtered = _signal_filter_bessel(signal, sampling_rate, lowcut, highcut, order)
         elif method in ["fir"]:
-            filtered = _signal_filter_fir(signal, sampling_rate, lowcut, highcut, window_size=window_size)
+            filtered = _signal_filter_fir(
+                signal, sampling_rate, lowcut, highcut, window_size=window_size
+            )
         else:
             raise ValueError(
                 "NeuroKit error: signal_filter(): 'method' should be",
                 " one of 'butterworth', 'butterworth_ba', 'bessel',",
-                " 'savgol' or 'fir'."
+                " 'savgol' or 'fir'.",
             )
+
+    if show is True:
+        plt.plot(signal, color="lightgrey")
+        plt.plot(filtered, color="red", alpha=0.9)
+
     return filtered
 
 
@@ -168,7 +178,9 @@ def _signal_filter_savgol(signal, sampling_rate=1000, order=2, window_size="defa
 # =============================================================================
 # FIR
 # =============================================================================
-def _signal_filter_fir(signal, sampling_rate=1000, lowcut=None, highcut=None, window_size="default"):
+def _signal_filter_fir(
+    signal, sampling_rate=1000, lowcut=None, highcut=None, window_size="default"
+):
     """Filter a signal using a FIR filter."""
     try:
         import mne
@@ -206,7 +218,9 @@ def _signal_filter_fir(signal, sampling_rate=1000, lowcut=None, highcut=None, wi
 
 def _signal_filter_butterworth(signal, sampling_rate=1000, lowcut=None, highcut=None, order=5):
     """Filter a signal using IIR Butterworth SOS method."""
-    freqs, filter_type = _signal_filter_sanitize(lowcut=lowcut, highcut=highcut, sampling_rate=sampling_rate)
+    freqs, filter_type = _signal_filter_sanitize(
+        lowcut=lowcut, highcut=highcut, sampling_rate=sampling_rate
+    )
 
     sos = scipy.signal.butter(order, freqs, btype=filter_type, output="sos", fs=sampling_rate)
     filtered = scipy.signal.sosfiltfilt(sos, signal)
@@ -216,7 +230,9 @@ def _signal_filter_butterworth(signal, sampling_rate=1000, lowcut=None, highcut=
 def _signal_filter_butterworth_ba(signal, sampling_rate=1000, lowcut=None, highcut=None, order=5):
     """Filter a signal using IIR Butterworth B/A method."""
     # Get coefficients
-    freqs, filter_type = _signal_filter_sanitize(lowcut=lowcut, highcut=highcut, sampling_rate=sampling_rate)
+    freqs, filter_type = _signal_filter_sanitize(
+        lowcut=lowcut, highcut=highcut, sampling_rate=sampling_rate
+    )
 
     b, a = scipy.signal.butter(order, freqs, btype=filter_type, output="ba", fs=sampling_rate)
     try:
@@ -233,7 +249,9 @@ def _signal_filter_butterworth_ba(signal, sampling_rate=1000, lowcut=None, highc
 
 
 def _signal_filter_bessel(signal, sampling_rate=1000, lowcut=None, highcut=None, order=5):
-    freqs, filter_type = _signal_filter_sanitize(lowcut=lowcut, highcut=highcut, sampling_rate=sampling_rate)
+    freqs, filter_type = _signal_filter_sanitize(
+        lowcut=lowcut, highcut=highcut, sampling_rate=sampling_rate
+    )
 
     sos = scipy.signal.bessel(order, freqs, btype=filter_type, output="sos", fs=sampling_rate)
     filtered = scipy.signal.sosfiltfilt(sos, signal)
@@ -270,7 +288,7 @@ def _signal_filter_sanitize(lowcut=None, highcut=None, sampling_rate=1000, norma
                 "The sampling rate is too low. Sampling rate"
                 " must exceed the Nyquist rate to avoid aliasing problem."
                 f" In this analysis, the sampling rate has to be higher than {2 * highcut} Hz",
-                category=NeuroKitWarning
+                category=NeuroKitWarning,
             )
 
     # Replace 0 by none
