@@ -11,12 +11,14 @@ def signal_formatpeaks(info, desired_length, peak_indices=None, other_indices=No
     signals = {}
     for feature, values in info.items():
         # Get indices of features
-        if feature != "SCR_RecoveryTime" and any(x in str(feature) for x in ["Peak", "Onset", "Offset", "Trough", "Recovery"]):
+        if feature != "SCR_RecoveryTime" and any(
+            x in str(feature) for x in ["Peak", "Onset", "Offset", "Trough", "Recovery"]
+        ):
             signals[feature] = _signal_from_indices(values, desired_length, 1)
-            signals[feature] = signals[feature].astype('int64')  # indexing of feature using 1 and 0
+            signals[feature] = signals[feature].astype("int64")  # indexing of feature using 1 and 0
 
         # Get values of features
-        elif 'RecoveryTime' in feature:
+        elif "RecoveryTime" in feature:
             # Sanitize indices and values
             other_indices, values = _signal_sanitize_indices(other_indices, values)
             # Append recovery time values to signal
@@ -30,10 +32,12 @@ def signal_formatpeaks(info, desired_length, peak_indices=None, other_indices=No
     signals = pd.DataFrame(signals)
     return signals
 
+
 # =============================================================================
 # Internals
 # =============================================================================
 
+
 def _signal_sanitize_indices(indices, values):
     # Check if nan in indices
     if np.sum(np.isnan(indices)) > 0:
@@ -44,6 +48,7 @@ def _signal_sanitize_indices(indices, values):
 
     return indices, values
 
+
 def _signal_from_indices(indices, desired_length=None, value=1):
     """Generates array of 0 and given values at given indices.
 
@@ -53,9 +58,9 @@ def _signal_from_indices(indices, desired_length=None, value=1):
     # signal = np.zeros(desired_length, dtype=float)
     signal = pd.Series(np.zeros(desired_length, dtype=float))
 
-    if isinstance(indices, list) and (not indices):    # skip empty lists
+    if isinstance(indices, list) and (not indices):  # skip empty lists
         return signal
-    if isinstance(indices, np.ndarray) and (indices.size == 0):    # skip empty arrays
+    if isinstance(indices, np.ndarray) and (indices.size == 0):  # skip empty arrays
         return signal
 
     # Force indices as int
@@ -81,7 +86,9 @@ def _signal_from_indices(indices, desired_length=None, value=1):
     return signal
 
 
-def _signal_formatpeaks_sanitize(peaks, key="Peaks"):    # FIXME: private function not used in this module
+def _signal_formatpeaks_sanitize(
+    peaks, key="Peaks"
+):  # FIXME: private function not used in this module
     # Attempt to retrieve column.
     if isinstance(peaks, tuple):
         if isinstance(peaks[0], (dict, pd.DataFrame)):
